@@ -17,11 +17,15 @@ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLI
 #include <algorithm>
 #include <cmath>
 
+#include <pybind11/pybind11.h>
+
 #include "config.hpp"
 #include "types.hpp"
 #include "curve.hpp"
 #include "frechet.hpp"
 
+namespace py = pybind11;
+
 namespace Simplification {
 
 class Subcurve_Shortcut_Graph {
@@ -32,7 +36,7 @@ class Subcurve_Shortcut_Graph {
 public:
     
     Subcurve_Shortcut_Graph(Curve &curve) : curve{curve}, edges{std::vector<Distances>(curve.complexity(), Distances(curve.complexity(), std::numeric_limits<distance_t>::infinity()))} {
-        if (Config::verbosity > 1) std::cout << "SIMPL: computing shortcut graph" << std::endl;
+        if (Config::verbosity > 1) py::print("SIMPL: computing shortcut graph");
         const curve_size_t complexity = curve.complexity();
         Curve segment(2, curve.front().dimensions());
         auto distance = Frechet::Continuous::Distance();
@@ -40,7 +44,7 @@ public:
         for (curve_size_t i = 0; i < complexity - 1; ++i) {
             for (curve_size_t j = i + 1; j < complexity; ++j) {
                 
-                if (Config::verbosity > 1) std::cout << "SIMPL: computing shortcut distance from vertex " << i << " to vertex " << j << std::endl;
+                if (Config::verbosity > 1) py::print("SIMPL: computing shortcut distance from vertex ", i, " to vertex ", j);
                 
                 curve.set_subcurve(i, j);
                 
@@ -57,7 +61,7 @@ public:
     }
     
     Curve minimum_error_simplification(const curve_size_t ll) const {
-        if (Config::verbosity > 1) std::cout << "SIMPL: computing exact minimum error simplification using shortcut graph" << std::endl;
+        if (Config::verbosity > 1) py::print("SIMPL: computing exact minimum error simplification using shortcut graph");
         if (ll >= curve.complexity()) return curve;
         
         const curve_size_t l = ll - 1;
@@ -78,7 +82,7 @@ public:
         for (curve_size_t i = 0; i < l; ++i) {
             
             if (i == 0) {
-                if (Config::verbosity > 1) std::cout << "SIMPL: initializing arrays" << std::endl;
+                if (Config::verbosity > 1) py::print("SIMPL: initializing arrays");
                 #pragma omp parallel for
                 for (curve_size_t j = 1; j < curve.complexity(); ++j) {
                     distances[j][0] = edges[0][j];
@@ -86,7 +90,7 @@ public:
                 }
             } else {
                 for (curve_size_t j = 1; j < curve.complexity(); ++j) {
-                    if (Config::verbosity > 1) std::cout << "SIMPL: computing shortcut using " << i << " jumps" << std::endl;
+                    if (Config::verbosity > 1) py::print("SIMPL: computing shortcut using ", i, " jumps");
                     others.resize(j);
                     #pragma omp parallel for
                     for (curve_size_t k = 0; k < j; ++k) {
@@ -101,7 +105,7 @@ public:
             }
         }
         
-        if (Config::verbosity > 1) std::cout << "SIMPL: backwards constructing simplification" << std::endl;
+        if (Config::verbosity > 1) py::print("SIMPL: backwards constructing simplification");
         
         curve_size_t ell = l - 1;
         
